<?xml version='1.0' encoding='UTF-8'?><!-- -*- indent-tabs-mode: nil -*- -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:yelp="http://www.gnome.org/yelp/ns"
                xmlns="http://www.w3.org/1999/xhtml"
                extension-element-prefixes="yelp"
                version="1.0">

<xsl:param name="help_icon"/>
<xsl:param name="help_icon_size"/>

<xsl:param name="yelp.javascript"/>
<xsl:param name="yelp.topimage"/>

<xsl:param name="yelp.color.fg"/>
<xsl:param name="yelp.color.bg"/>
<xsl:param name="yelp.color.anchor"/>
<xsl:param name="yelp.color.rule"/>
<xsl:param name="yelp.color.gray.fg"/>
<xsl:param name="yelp.color.gray.bg"/>
<xsl:param name="yelp.color.gray.bg.dark1"/>
<xsl:param name="yelp.color.gray.bg.dark2"/>
<xsl:param name="yelp.color.gray.bg.dark3"/>
<xsl:param name="yelp.color.selected.fg"/>
<xsl:param name="yelp.color.selected.bg"/>
<xsl:param name="yelp.color.selected.bg.dark1"/>
<xsl:param name="yelp.color.selected.bg.dark2"/>
<xsl:param name="yelp.color.selected.bg.dark3"/>
<xsl:param name="yelp.color.admon.fg"/>
<xsl:param name="yelp.color.admon.bg"/>
<xsl:param name="yelp.color.admon.bg.dark1"/>
<xsl:param name="yelp.color.admon.bg.dark2"/>
<xsl:param name="yelp.color.admon.bg.dark3"/>

<xsl:template match="toc">
  <yelp:document href="{@id}">
    <html>
      <head>
        <title>
          <xsl:value-of select="title[1]"/>
        </title>
        <script type="text/javascript">
          <xsl:attribute name="src">
            <xsl:value-of select="concat('file://', $yelp.javascript)"/>
          </xsl:attribute>
        </script>
        <style type="text/css"><xsl:text>
 
        body {
          margin: 0px;
          padding: 0px;
          background: white;
          background-image: url("</xsl:text>
          <xsl:value-of select="$yelp.topimage"/><xsl:text>");
          background-position: 0px 0px;
          background-repeat: no-repeat;
          font-family: Segoe, Sans;
          font-size: 11px;
          position: absolute;
          width: 100%;
        }
        div.content {
          margin-top: 30px;
          padding: 12px;
          padding-top: 2px;
          padding-left: 38px;
        }
        #index-header {
          margin-top: 12px;
          color: #333366;
          font-size: 32px;
        }
        h1 img {
          position: relative;
          top: -6px;
          right: 18px;
          display: none;
        }
        h1 {
          margin: 0px;
          padding: 3px;
          font-size: 16pt;
        }
        li.toc li.toc h1 {
          font-size: 12pt;
        }
        h1.child {
          color: #003399;
        }
        h1.child:hover {
          text-decoration: underline;
          background: #e9ece0;
          -moz-border-radius: 5px;
          color: #003399;
          cursor: pointer;
        }
        div.docs dl dt {
          font-size: 10pt;
          margin-left: 24px;
          margin-top: 6px;
        }
        div.docs dl dd {
          font-size: 9pt;
          color: #999999;
          margin-left: 36px;
        }
        div.docs a {
          color: #003399;
          text-decoration: none;
        }
        div.docs a:hover {
          cursor: pointer;
          text-decoration: underline;
        }
        ul { font-size: 1em; margin-left: 0em; padding-left: 0em; }

        li {
          margin-top: 2px;
          margin-left: 32px;
          padding-left: 0em;
          list-style-type: none;
        }
        div.collapse-action {
          font-size: 11px;
          color: red;
          position: absolute;
          top: 34px;
          right: 12px;
        }
        </xsl:text></style>
      </head>
      <body>
        <!-- <div class="collapse-action"><a href="javascript:expand_all()">Expand all categories</a></div> -->
        <xsl:apply-templates mode="body.mode" select="."/>
      </body>
    </html>
  </yelp:document>
</xsl:template>

<xsl:template name="header">
  <xsl:param name="class"/>
  <h1 id="{@id}-header" onclick="show_hide ('{@id}');" class="{$class}">
    <xsl:if test="icon">
      <img src="{icon/@file}"/>
    </xsl:if>
    <xsl:apply-templates select="title[1]/node()"/>
  </h1>
</xsl:template>

<xsl:template name="children">
  <xsl:param name="class"/>
  <div id="{@id}-children">
    <xsl:if test="@id != 'index'">
      <xsl:attribute name="style">
        <xsl:value-of select="'display: none'"/>
      </xsl:attribute>
    </xsl:if>
    <xsl:if test="@id = 'index' or toc[.//doc]">
      <div class="tocs">
        <ul>
          <xsl:for-each select="toc[../@id = 'index' or .//doc]">
<!--             <xsl:sort select="number(../@id = 'index') * position()"/>
            <xsl:sort select="normalize-space(title)"/>-->
            <li class="toc">
              <xsl:apply-templates mode="children.mode" select="."/>
            </li>
          </xsl:for-each>
        </ul>
      </div>
    </xsl:if>
    <xsl:if test="doc">
      <div class="docs">
        <dl>
          <xsl:for-each select="doc">
            <xsl:sort select="normalize-space(title)"/>
            <dt class="doc">
              <a href="{@href}" title="{@href}">
                <xsl:if test="tooltip">
                  <xsl:attribute name="title">
                    <xsl:value-of select="tooltip"/>
                  </xsl:attribute>
                </xsl:if>
                <xsl:value-of select="title"/>
              </a>
            </dt>
            <dd>
              <xsl:value-of select="description"/>
            </dd>
          </xsl:for-each>
        </dl>
      </div>
    </xsl:if>
  </div>
</xsl:template>

<xsl:template mode="body.mode" match="toc">
  <div class="content">
    <xsl:call-template name="header">
      <xsl:with-param name="class" select="'index'"/>
    </xsl:call-template>
    <div class="rightbar">
      <xsl:call-template name="children">
        <xsl:with-param name="class" select="'index'"/>
      </xsl:call-template>
    </div>
  </div>
</xsl:template>

<xsl:template mode="children.mode" match="toc">
  <xsl:call-template name="header">
    <xsl:with-param name="class" select="'child'"/>
  </xsl:call-template>
  <xsl:call-template name="children">
    <xsl:with-param name="class" select="'child'"/>
  </xsl:call-template>
</xsl:template>

</xsl:stylesheet>
